==> autoscaling-1.182.0-sources.jar: software/amazon/awscdk/services/autoscaling/TargetTrackingScalingPolicy.java <==
package software.amazon.awscdk.services.autoscaling;

/**
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.autoscaling.*;
 * import software.amazon.awscdk.services.cloudwatch.*;
 * import software.amazon.awscdk.core.*;
 * AutoScalingGroup autoScalingGroup;
 * Metric metric;
 * TargetTrackingScalingPolicy targetTrackingScalingPolicy = TargetTrackingScalingPolicy.Builder.create(this, "MyTargetTrackingScalingPolicy")
 *         .autoScalingGroup(autoScalingGroup)
 *         .targetValue(123)
 *         // the properties below are optional
 *         .cooldown(Duration.minutes(30))
 *         .customMetric(metric)
 *         .disableScaleIn(false)
 *         .estimatedInstanceWarmup(Duration.minutes(30))
 *         .predefinedMetric(PredefinedMetric.ASG_AVERAGE_CPU_UTILIZATION)
 *         .resourceLabel("resourceLabel")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-12-07T17:24:45.740Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.autoscaling.$Module.class, fqn = "@aws-cdk/aws-autoscaling.TargetTrackingScalingPolicy")
public class TargetTrackingScalingPolicy extends software.amazon.awscdk.core.Construct {

    protected TargetTrackingScalingPolicy(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TargetTrackingScalingPolicy(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public TargetTrackingScalingPolicy(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.autoscaling.TargetTrackingScalingPolicyProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * ARN of the scaling policy.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getScalingPolicyArn() {
        return software.amazon.jsii.Kernel.get(this, "scalingPolicyArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.autoscaling.TargetTrackingScalingPolicy}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.autoscaling.TargetTrackingScalingPolicy> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.autoscaling.TargetTrackingScalingPolicyProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.autoscaling.TargetTrackingScalingPolicyProps.Builder();
        }

        /**
         * Period after a scaling completes before another scaling activity can start.
         * <p>
         * Default: - The default cooldown configured on the AutoScalingGroup.
         * <p>
         * @return {@code this}
         * @param cooldown Period after a scaling completes before another scaling activity can start. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cooldown(final software.amazon.awscdk.core.Duration cooldown) {
            this.props.cooldown(cooldown);
            return this;
        }

        /**
         * Indicates whether scale in by the target tracking policy is disabled.
         * <p>
         * If the value is true, scale in is disabled and the target tracking policy
         * won't remove capacity from the autoscaling group. Otherwise, scale in is
         * enabled and the target tracking policy can remove capacity from the
         * group.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param disableScaleIn Indicates whether scale in by the target tracking policy is disabled. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder disableScaleIn(final java.lang.Boolean disableScaleIn) {
            this.props.disableScaleIn(disableScaleIn);
            return this;
        }

        /**
         * Estimated time until a newly launched instance can send metrics to CloudWatch.
         * <p>
         * Default: - Same as the cooldown.
         * <p>
         * @return {@code this}
         * @param estimatedInstanceWarmup Estimated time until a newly launched instance can send metrics to CloudWatch. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder estimatedInstanceWarmup(final software.amazon.awscdk.core.Duration estimatedInstanceWarmup) {
            this.props.estimatedInstanceWarmup(estimatedInstanceWarmup);
            return this;
        }

        /**
         * The target value for the metric.
         * <p>
         * @return {@code this}
         * @param targetValue The target value for the metric. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetValue(final java.lang.Number targetValue) {
            this.props.targetValue(targetValue);
            return this;
        }

        /**
         * A custom metric for application autoscaling.
         * <p>
         * The metric must track utilization. Scaling out will happen if the metric is higher than
         * the target value, scaling in will happen in the metric is lower than the target value.
         * <p>
         * Exactly one of customMetric or predefinedMetric must be specified.
         * <p>
         * Default: - No custom metric.
         * <p>
         * @return {@code this}
         * @param customMetric A custom metric for application autoscaling. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder customMetric(final software.amazon.awscdk.services.cloudwatch.IMetric customMetric) {
            this.props.customMetric(customMetric);
            return this;
        }

        /**
         * A predefined metric for application autoscaling.
         * <p>
         * The metric must track utilization. Scaling out will happen if the metric is higher than
         * the target value, scaling in will happen in the metric is lower than the target value.
         * <p>
         * Exactly one of customMetric or predefinedMetric must be specified.
         * <p>
         * Default: - No predefined metric.
         * <p>
         * @return {@code this}
         * @param predefinedMetric A predefined metric for application autoscaling. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder predefinedMetric(final software.amazon.awscdk.services.autoscaling.PredefinedMetric predefinedMetric) {
            this.props.predefinedMetric(predefinedMetric);
            return this;
        }

        /**
         * The resource label associated with the predefined metric.
         * <p>
         * Should be supplied if the predefined metric is ALBRequestCountPerTarget, and the
         * format should be:
         * <p>
         * app/<load-balancer-name>/<load-balancer-id>/targetgroup/<target-group-name>/<target-group-id>
         * <p>
         * Default: - No resource label.
         * <p>
         * @return {@code this}
         * @param resourceLabel The resource label associated with the predefined metric. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resourceLabel(final java.lang.String resourceLabel) {
            this.props.resourceLabel(resourceLabel);
            return this;
        }

        /**
         * @return {@code this}
         * @param autoScalingGroup This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder autoScalingGroup(final software.amazon.awscdk.services.autoscaling.IAutoScalingGroup autoScalingGroup) {
            this.props.autoScalingGroup(autoScalingGroup);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.autoscaling.TargetTrackingScalingPolicy}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.autoscaling.TargetTrackingScalingPolicy build() {
            return new software.amazon.awscdk.services.autoscaling.TargetTrackingScalingPolicy(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> autoscaling-1.204.0-sources.jar: software/amazon/awscdk/services/autoscaling/TargetTrackingScalingPolicy.java <==
package software.amazon.awscdk.services.autoscaling;

/**
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.autoscaling.*;
 * import software.amazon.awscdk.services.cloudwatch.*;
 * import software.amazon.awscdk.core.*;
 * AutoScalingGroup autoScalingGroup;
 * Metric metric;
 * TargetTrackingScalingPolicy targetTrackingScalingPolicy = TargetTrackingScalingPolicy.Builder.create(this, "MyTargetTrackingScalingPolicy")
 *         .autoScalingGroup(autoScalingGroup)
 *         .targetValue(123)
 *         // the properties below are optional
 *         .cooldown(Duration.minutes(30))
 *         .customMetric(metric)
 *         .disableScaleIn(false)
 *         .estimatedInstanceWarmup(Duration.minutes(30))
 *         .predefinedMetric(PredefinedMetric.ASG_AVERAGE_CPU_UTILIZATION)
 *         .resourceLabel("resourceLabel")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.84.0 (build 5404dcf)", date = "2023-06-19T16:30:45.421Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.autoscaling.$Module.class, fqn = "@aws-cdk/aws-autoscaling.TargetTrackingScalingPolicy")
public class TargetTrackingScalingPolicy extends software.amazon.awscdk.core.Construct {

    protected TargetTrackingScalingPolicy(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected TargetTrackingScalingPolicy(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public TargetTrackingScalingPolicy(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.autoscaling.TargetTrackingScalingPolicyProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * ARN of the scaling policy.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getScalingPolicyArn() {
        return software.amazon.jsii.Kernel.get(this, "scalingPolicyArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.autoscaling.TargetTrackingScalingPolicy}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.autoscaling.TargetTrackingScalingPolicy> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.autoscaling.TargetTrackingScalingPolicyProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.autoscaling.TargetTrackingScalingPolicyProps.Builder();
        }

        /**
         * Period after a scaling completes before another scaling activity can start.
         * <p>
         * Default: - The default cooldown configured on the AutoScalingGroup.
         * <p>
         * @return {@code this}
         * @param cooldown Period after a scaling completes before another scaling activity can start. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cooldown(final software.amazon.awscdk.core.Duration cooldown) {
            this.props.cooldown(cooldown);
            return this;
        }

        /**
         * Indicates whether scale in by the target tracking policy is disabled.
         * <p>
         * If the value is true, scale in is disabled and the target tracking policy
         * won't remove capacity from the autoscaling group. Otherwise, scale in is
         * enabled and the target tracking policy can remove capacity from the
         * group.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param disableScaleIn Indicates whether scale in by the target tracking policy is disabled. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder disableScaleIn(final java.lang.Boolean disableScaleIn) {
            this.props.disableScaleIn(disableScaleIn);
            return this;
        }

        /**
         * Estimated time until a newly launched instance can send metrics to CloudWatch.
         * <p>
         * Default: - Same as the cooldown.
         * <p>
         * @return {@code this}
         * @param estimatedInstanceWarmup Estimated time until a newly launched instance can send metrics to CloudWatch. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder estimatedInstanceWarmup(final software.amazon.awscdk.core.Duration estimatedInstanceWarmup) {
            this.props.estimatedInstanceWarmup(estimatedInstanceWarmup);
            return this;
        }

        /**
         * The target value for the metric.
         * <p>
         * @return {@code this}
         * @param targetValue The target value for the metric. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder targetValue(final java.lang.Number targetValue) {
            this.props.targetValue(targetValue);
            return this;
        }

        /**
         * A custom metric for application autoscaling.
         * <p>
         * The metric must track utilization. Scaling out will happen if the metric is higher than
         * the target value, scaling in will happen in the metric is lower than the target value.
         * <p>
         * Exactly one of customMetric or predefinedMetric must be specified.
         * <p>
         * Default: - No custom metric.
         * <p>
         * @return {@code this}
         * @param customMetric A custom metric for application autoscaling. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder customMetric(final software.amazon.awscdk.services.cloudwatch.IMetric customMetric) {
            this.props.customMetric(customMetric);
            return this;
        }

        /**
         * A predefined metric for application autoscaling.
         * <p>
         * The metric must track utilization. Scaling out will happen if the metric is higher than
         * the target value, scaling in will happen in the metric is lower than the target value.
         * <p>
         * Exactly one of customMetric or predefinedMetric must be specified.
         * <p>
         * Default: - No predefined metric.
         * <p>
         * @return {@code this}
         * @param predefinedMetric A predefined metric for application autoscaling. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder predefinedMetric(final software.amazon.awscdk.services.autoscaling.PredefinedMetric predefinedMetric) {
            this.props.predefinedMetric(predefinedMetric);
            return this;
        }

        /**
         * The resource label associated with the predefined metric.
         * <p>
         * Should be supplied if the predefined metric is ALBRequestCountPerTarget, and the
         * format should be:
         * <p>
         * app/<load-balancer-name>/<load-balancer-id>/targetgroup/<target-group-name>/<target-group-id>
         * <p>
         * Default: - No resource label.
         * <p>
         * @return {@code this}
         * @param resourceLabel The resource label associated with the predefined metric. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder resourceLabel(final java.lang.String resourceLabel) {
            this.props.resourceLabel(resourceLabel);
            return this;
        }

        /**
         * @return {@code this}
         * @param autoScalingGroup This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder autoScalingGroup(final software.amazon.awscdk.services.autoscaling.IAutoScalingGroup autoScalingGroup) {
            this.props.autoScalingGroup(autoScalingGroup);
            return this;
        }

        /**
         * @return a newly built instance of {@link software.amazon.awscdk.services.autoscaling.TargetTrackingScalingPolicy}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.autoscaling.TargetTrackingScalingPolicy build() {
            return new software.amazon.awscdk.services.autoscaling.TargetTrackingScalingPolicy(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
